#' @noRd
.onAttach <- function(libname, pkgname) {
  packageStartupMessage("reflectR: a package to automatically code open-ended responses to the Cognitive Reflection Test.")
  packageStartupMessage("For more information on getting started, type ?reflectR.")
  packageStartupMessage("For suggestions or to report issues, please contact Giuseppe Corbelli at giuseppe.corbelli@uninettunouniversity.net or giuseppe.corbelli@uniroma1.it.")
}
